###############################################
MKS Instruments 974B Vacuum Pressure Transducer
###############################################

.. autoclass:: pymeasure.instruments.mksinst.mks974b.MKS974B
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.mksinst.mks974b.Relay
    :members:
    :show-inheritance:
